@@ -6,8 +6,9 @@ import json
 
 from abc import abstractmethod
 from pathlib import Path
-import re
+import socket
 from typing import Any, List, Optional, Union, final
+from urllib.parse import urlparse
 from packageurl import PackageURL  # type: ignore
 
 from hoppr_cyclonedx_models.cyclonedx_1_4 import Component
@@ -49,6 +50,31 @@ class BaseCollectorPlugin(HopprPlugin):
 
         return directory
 
+    @staticmethod
+    def _parse_url_for_comparison(url: str) -> tuple[str, str, str]:
+        """
+        Resulting tuple is (host, port, path)
+        """
+        if url.startswith("file:") or "//" in url:
+            initial_parse = urlparse(url)
+        else:
+            initial_parse = urlparse("//" + url)
+
+        host_data = initial_parse.netloc.split(":")
+
+        host = host_data[0]
+
+        if len(host_data) > 1:
+            port = host_data[1]
+        elif initial_parse.scheme == "":
+            port = ""
+        else:
+            port = str(socket.getservbyname(initial_parse.scheme))
+
+        path = initial_parse.path.rstrip("/")
+
+        return (host, port, path)
+
     @staticmethod
     def check_purl_specified_url(purl: PackageURL, repo_url: str) -> Result:
         """
@@ -63,9 +89,15 @@ class BaseCollectorPlugin(HopprPlugin):
         if purl_url is None:
             return Result.success()
 
-        trimmed_purl_url = re.sub(r"(ssh|file|https?)://", "", purl_url).rstrip("/")
-        trimmed_repo_url = re.sub(r"(ssh|file|https?)://", "", repo_url).rstrip("/")
-        if trimmed_repo_url.startswith(trimmed_purl_url):
+        parsed_purl_url = BaseCollectorPlugin._parse_url_for_comparison(purl_url)
+        parsed_repo_url = BaseCollectorPlugin._parse_url_for_comparison(repo_url)
+        print(f"DEBUG: Purl: {parsed_purl_url}")
+        print(f"DEBUG: repo: {parsed_repo_url}")
+        if (
+            parsed_repo_url[0] == parsed_purl_url[0]
+            and (not parsed_purl_url[1] or parsed_repo_url[1] == parsed_purl_url[1])
+            and parsed_repo_url[2].startswith(parsed_purl_url[2])
+        ):
             return Result.success()
 
         return Result.fail(
