@@ -90,19 +90,13 @@ class CollectDnfPlugin(BatchCollectorPlugin):
             "--enablerepo=hoppr-tmp-*",
         ]
 
-    def _get_component_path(self, found_url: str) -> Union[Path, None]:
+    def _get_found_repo(self, found_url: str) -> Union[str, None]:
         """
-        Create subdirectory path consisting of found URL
-        with the manifest repo and RPM file name removed
+        Identify the repository associated with the specified URL
         """
         for repo in self.manifest_repos:
             if found_url.startswith(repo):
-                found_url_path = Path(found_url)
-                subdir = found_url_path.relative_to(repo).parent
-
-                return self.directory_for(
-                    self.supported_purl_types[0], repo, subdir=str(subdir)
-                )
+                return repo
 
         return None
 
@@ -176,31 +170,39 @@ class CollectDnfPlugin(BatchCollectorPlugin):
 
         # Try getting RPM URL
         command = [*self.base_command, "repoquery", "--location", artifact]
-        result = self.run_command(command, self.password_list)
+        run_result = self.run_command(command, self.password_list)
 
         # If RPM URL not found, no need to try downloading it
-        if result.returncode != 0 or len(result.stdout.decode("utf-8")) == 0:
+        if run_result.returncode != 0 or len(run_result.stdout.decode("utf-8")) == 0:
             msg = f"{self.required_commands[0]} failed to locate package for {purl}"
             self.get_logger().debug(msg)
 
             return Result.retry(msg)
 
         # Taking the first URL if multiple are returned
-        found_url = result.stdout.decode("utf-8").strip().split("\n")[0]
-        target_dir = self._get_component_path(found_url)
+        found_url = run_result.stdout.decode("utf-8").strip().split("\n")[0]
 
+        repo = self._get_found_repo(found_url)
         # Return failure if found RPM URL is not from a repo defined in the manifest
-        if target_dir is None:
+        if repo is None:
             return Result.fail(
                 "Successfully found RPM file but URL does not match any repository in manifest."
                 f" (Found URL: '{found_url}')"
             )
 
+        result = self.check_purl_specified_url(purl, repo)
+        if not result.is_success():
+            return result
+
+        found_url_path = Path(found_url)
+        subdir = found_url_path.relative_to(repo).parent
+        target_dir = self.directory_for(purl.type, repo, subdir=str(subdir))
+
         # Download the RPM file to the new directory
         command = [*self.base_command, "download", f"--destdir={target_dir}", artifact]
-        result = self.run_command(command, password_list=self.password_list)
+        run_result = self.run_command(command, password_list=self.password_list)
 
-        if result.returncode != 0:
+        if run_result.returncode != 0:
             msg = f"Failed to download DNF artifact {purl.name} version {purl.version}"
             return Result.retry(msg)
 
