@@ -42,6 +42,9 @@ class CollectHelmPlugin(SerialCollectorPlugin):
         """
 
         purl = PackageURL.from_string(comp.purl)
+        helm_result = self.check_purl_specified_url(purl, repo_url)
+        if not helm_result.is_success():
+            return helm_result
 
         target_dir = self.directory_for(
             purl.type, repo_url, subdir=f"{purl.name}_{purl.version}"
@@ -73,8 +76,8 @@ class CollectHelmPlugin(SerialCollectorPlugin):
                 ]
                 password_list = [creds.password]
 
-            result = self.run_command(command, password_list)
-            if result.returncode == 0:
+            run_result = self.run_command(command, password_list)
+            if run_result.returncode == 0:
                 self.get_logger().info(
                     f"Complete helm chart artifact copy for {purl.to_string()}"
                 )
