@@ -39,6 +39,10 @@ class CollectPypiPlugin(SerialCollectorPlugin):
         Copy a component to the local collection directory structure
         """
         purl = PackageURL.from_string(comp.purl)
+        result = self.check_purl_specified_url(purl, repo_url)
+        if not result.is_success():
+            return result
+
         if not repo_url.endswith("simple") or repo_url.endswith("simple/"):
             source_url = os.path.join(repo_url, "simple")
         password_list = []
@@ -73,8 +77,8 @@ class CollectPypiPlugin(SerialCollectorPlugin):
 
         got_binary = True
 
-        result = self.run_command(command, password_list)
-        if result.returncode != 0:
+        run_result = self.run_command(command, password_list)
+        if run_result.returncode != 0:
             self.get_logger().error(
                 f"Failed to download {purl.name} version {purl.version} binary"
             )
@@ -82,8 +86,8 @@ class CollectPypiPlugin(SerialCollectorPlugin):
 
         command[-1] = "--no-binary=:all:"
 
-        result = self.run_command(command, password_list)
-        if result.returncode != 0:
+        run_result = self.run_command(command, password_list)
+        if run_result.returncode != 0:
             self.get_logger().error(
                 f"Failed to download {purl.name} version {purl.version} source"
             )
