@@ -50,10 +50,16 @@ class CollectRawPlugin(SerialCollectorPlugin):
         file_name = unquote(purl.name)
 
         if source_url.scheme == "file":
+            source_url = urlparse(repo_url + (purl.namespace or ""))
             source_file = Path(source_url.path, file_name).expanduser()
 
+            self.get_logger().info(
+                f"Copying from {source_file} to {target_dir.joinpath(file_name)}"
+            )
             if not source_file.is_file():
-                return Result.fail(f"Unable to locate file {source_file}")
+                msg = f"Unable to locate file {source_file}"
+                self.get_logger().info(msg)
+                return Result.fail(msg)
 
             self.get_logger().info(
                 f"Copying file from {source_file} to directory {target_dir}"
@@ -61,7 +67,7 @@ class CollectRawPlugin(SerialCollectorPlugin):
             shutil.copy(source_file, target_dir)
             return Result.success()
 
-        download_url = urljoin(source_url.geturl(), file_name)
+        download_url = urljoin(source_url.geturl() + "/", file_name)
 
         self.get_logger().info(
             f"Downloading from {download_url} to file {target_dir.joinpath(file_name)}"
